@@ -81,6 +81,7 @@ if(epithet) {
     x <- paste(substr(x, 1, regexpr('\ ', x)-1), gsub('on\\b', '', substr(x, regexpr('\ ', x), nchar(x))), sep='')
     x <- paste(substr(x, 1, regexpr('\ ', x)-1), gsub('um\\b', '', substr(x, regexpr('\ ', x), nchar(x))), sep='')
     x <- paste(substr(x, 1, regexpr('\ ', x)-1), gsub('us\\b', '', substr(x, regexpr('\ ', x), nchar(x))), sep='')
+    x <- paste(substr(x, 1, regexpr('\ ', x)-1), gsub('ae', 'e', substr(x, regexpr('\ ', x), nchar(x))), sep='')    
 }
 if(genus) {
     x <-	paste(sub('a$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
@@ -104,42 +105,32 @@ return(x)
 
 
 TCS.replace <- function(x) {
-## Turboveg  
-  x <- replace(x, x=='ABBREVIAT', 'TaxonName')
-  x <- replace(x, x=='taxonName', 'TaxonName')
-  x <- replace(x, x=='Taxon', 'TaxonName')
-  x <- replace(x, x=='SPECIES_NR', 'TaxonUsageID')
-  x <- replace(x, x=='VALID_NAME', 'TaxonConcept')
-  x <- replace(x, x=='VALID_NR', 'TaxonConceptID')
-  x <- replace(x, x=='AGG_NAME', 'IsChildTaxonOf')
-  x <- replace(x, x=='AGG', 'IsChildTaxonOfID')
-  x <- replace(x, x=='SECUNDUM', 'AccordingTo')
-  x <- replace(x, x=='NATIVENAME', 'VernacularName')
-  x <- replace(x, x=='RANG', 'TaxonRank')
-  x <- replace(x, x=='CLASSIFICA', 'Classification')
-## Florkart Germany (BfN lists)
-  x <- replace(x, x=='TAXNAME', 'TaxonName')
-  x <- replace(x, x=='sipnr', 'TaxonConceptID')
-  x <- replace(x, x=='SIPNR', 'TaxonConceptID')
-  x <- replace(x, x=='namnr', 'TaxonUsageID')
-  x <- replace(x, x=='NAMNR', 'TaxonUsageID')
-  x <- replace(x, x=='TAXNR', 'TaxonUsageID')
-  x <- replace(x, x=='AGG_NAME', 'IsChildTaxonOf')
-  x <- replace(x, x=='AGGNR', 'IsChildTaxonOfID')
-  x <- replace(x, x=='RANK', 'TaxonRank')  
-  x <- replace(x, x=='Rank', 'TaxonRank')  
+  x <- toupper(x)
+## Turboveg & ## Florkart Germany (BfN lists)
+x <- replace(x, x %in% c('SPECIES_NR', 'TAXNR', 'NAMNR', 'NAMEID'), 'TaxonUsageID')
+x <- replace(x, x %in% c('ABBREVIAT','TAXONANME','TAXON','TAXNAME'), 'TaxonName')
+x <- replace(x, x %in% c('VALID_NR', 'SIPNR', 'SYNNAMEID'), 'TaxonConceptID')
+x <- replace(x, x %in% c('VALID_NAME'), 'TaxonConcept')
+x <- replace(x, x %in% c('AGG', 'AGGNR', 'NAMEPARENTID'), 'IsChildTaxonOfID')
+x <- replace(x, x %in% c('AGG_NAME'), 'IsChildTaxonOf')
+x <- replace(x, x %in% c('SECUNDUM'), 'AccordingTo')
+x <- replace(x, x %in% c('NATIVENAME', "COMMONNAME"), 'VernacularName')
+x <- replace(x, x %in% c('CLASSIFICA'), 'Classification')
+x <- replace(x, x %in% c('RANG', 'RANK', "TAXONOMICRANK"), 'TaxonRank')
+
 ## ESveg
-  x <- replace(x, x=="taxonCode", 'TaxonUsageID')
-  x <- replace(x, x=="observationCode", "RELEVE_NR")
-  x <- replace(x, x=="ObservationID", "RELEVE_NR")
-  x <- replace(x, x=="stratumCode", "LAYER")
-  x <- replace(x, x=="Stratum", "LAYER")
-  x <- replace(x, x=="Percentage_mean", "COVER_PERC")
-  x <- replace(x, x=="coverPercent", "COVER_PERC")
+  x <- replace(x, x=="TAXONCODE", 'TaxonUsageID')
+  x <- replace(x, x=="OBSERVATIONCODE", "RELEVE_NR")
+  x <- replace(x, x=="OBSERVATIONID", "RELEVE_NR")
+  x <- replace(x, x=="STRATUMCODE", "LAYER")
+  x <- replace(x, x=="STRATUM", "LAYER")
+  x <- replace(x, x=="PERCENTAGE_MEAN", "COVER_PERC")
+  x <- replace(x, x=="COVERPERCENT", "COVER_PERC")
+
 ## CDM
-  x <- replace(x, x=='Taxon', 'TaxonName')
-  x <- replace(x, x=='SynUUID', 'TaxonUsageID')
-  x <- replace(x, x=='accTaxonId', 'TaxonConceptID')
+  x <- replace(x, x=='TAXON', 'TaxonName')
+  x <- replace(x, x=='SYNUUID', 'TaxonUsageID')
+  x <- replace(x, x=='ACCTAXONID', 'TaxonConceptID')
   return(x)
 }
 
